summaryrefslogtreecommitdiffstats
path: root/src/mainwindow.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:06:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:06:16 -0600
commit7717bcec2ad7d94e3f38a2e831bafa60a525f7d2 (patch)
tree77ffa8fe14318bb3a285cae65dbe622bcbbcb3f9 /src/mainwindow.h
parentb5cff83092d97189b5a55e1a996995207bc3016c (diff)
downloadtellico-7717bcec2ad7d94e3f38a2e831bafa60a525f7d2.tar.gz
tellico-7717bcec2ad7d94e3f38a2e831bafa60a525f7d2.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'src/mainwindow.h')
-rw-r--r--src/mainwindow.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/src/mainwindow.h b/src/mainwindow.h
index 4c2e5be..087869e 100644
--- a/src/mainwindow.h
+++ b/src/mainwindow.h
@@ -22,13 +22,13 @@
#include <kmainwindow.h>
-class KToolBar;
+class TDEToolBar;
class KURL;
-class KAction;
-class KSelectAction;
-class KToggleAction;
-class KRecentFilesAction;
-class KActionMenu;
+class TDEAction;
+class TDESelectAction;
+class TDEToggleAction;
+class TDERecentFilesAction;
+class TDEActionMenu;
class KDialogBase;
class TQCloseEvent;
@@ -61,16 +61,16 @@ namespace Tellico {
/**
* The base class for Tellico application windows. It sets up the main
* window and reads the config file as well as providing a menubar, toolbar
* and statusbar. Tellico reimplements the methods that KMainWindow provides
* for main window handling and supports full session management as well as
- * using KActions.
- * @see KMainWindow
+ * using TDEActions.
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig
*
* @author Robby Stephenson
*/
-class MainWindow : public KMainWindow, public ApplicationInterface {
+class MainWindow : public TDEMainWindow, public ApplicationInterface {
Q_OBJECT
@@ -307,7 +307,7 @@ private:
*/
void readOptions();
/**
- * Initializes the KActions of the application
+ * Initializes the TDEActions of the application
*/
void initActions();
/**
@@ -335,7 +335,7 @@ private:
* Saves the window properties for each open window during session end to the
* session config file, including saving the currently opened file by a temporary
* filename provided by TDEApplication.
- * @see KMainWindow::saveProperties
+ * @see TDEMainWindow::saveProperties
*
* @param cfg The config class with the properties to restore
*/
@@ -344,7 +344,7 @@ private:
* Reads the session config file and restores the application's state including
* the last opened files and documents by reading the temporary files saved by
* @ref saveProperties().
- * @see KMainWindow::readProperties
+ * @see TDEMainWindow::readProperties
*
* @param cfg The config class with the properties to restore
*/
@@ -355,13 +355,13 @@ private:
*
* The purpose of this function is to prepare the window in a way that it is safe to close it,
* i.e. without the user losing some data.
- * @see KMainWindow::queryClose
+ * @see TDEMainWindow::queryClose
*/
bool queryClose();
/**
* Called before the very last window is closed, either by the user
* or indirectly by the session manager.
- * @see KMainWindow::queryExit
+ * @see TDEMainWindow::queryExit
*/
bool queryExit();
/**
@@ -479,22 +479,22 @@ private:
// the reason that I have to keep pointers to all these
// is because they get plugged into menus later in Controller
- KRecentFilesAction* m_fileOpenRecent;
- KAction* m_fileSave;
- KAction* m_newEntry;
- KAction* m_editEntry;
- KAction* m_copyEntry;
- KAction* m_deleteEntry;
- KAction* m_mergeEntry;
- KActionMenu* m_updateEntryMenu;
- KAction* m_updateAll;
- KAction* m_checkInEntry;
- KAction* m_checkOutEntry;
- KToggleAction* m_toggleGroupWidget;
- KToggleAction* m_toggleEntryEditor;
- KToggleAction* m_toggleEntryView;
+ TDERecentFilesAction* m_fileOpenRecent;
+ TDEAction* m_fileSave;
+ TDEAction* m_newEntry;
+ TDEAction* m_editEntry;
+ TDEAction* m_copyEntry;
+ TDEAction* m_deleteEntry;
+ TDEAction* m_mergeEntry;
+ TDEActionMenu* m_updateEntryMenu;
+ TDEAction* m_updateAll;
+ TDEAction* m_checkInEntry;
+ TDEAction* m_checkOutEntry;
+ TDEToggleAction* m_toggleGroupWidget;
+ TDEToggleAction* m_toggleEntryEditor;
+ TDEToggleAction* m_toggleEntryView;
- KSelectAction* m_entryGrouping;
+ TDESelectAction* m_entryGrouping;
GUI::LineEdit* m_quickFilter;
// m_split is used between the stuff on the left and stuff on the right
@@ -519,7 +519,7 @@ private:
FetchDialog* m_fetchDlg;
ReportDialog* m_reportDlg;
- TQPtrList<KAction> m_fetchActions;
+ TQPtrList<TDEAction> m_fetchActions;
CollectionInterface m_collInterface;
// keep track of the number of queued filter updates
@@ -61,16 +61,16 @@ namespace Tellico {
* The base class for Tellico application windows. It sets up the main
* window and reads the config file as well as providing a menubar, toolbar
- * and statusbar. Tellico reimplements the methods that KMainWindow provides
+ * and statusbar. Tellico reimplements the methods that TDEMainWindow provides
* for main window handling and supports full session management as well as